@@ -28,8 +28,11 @@ import rpy2.robjects.numpy2ri as numpy2ri
 
 ISOdatetime = rinterface.baseenv['ISOdatetime']
 
-converter = conversion.make_converter('original pandas conversion')
-converter_name, py2ri, ri2ro, py2ro, ri2py, converter_lineage = converter
+converter = conversion.Converter('original pandas conversion')
+py2ri = converter.py2ri
+py2ro = converter.py2ro
+ri2py = converter.ri2py
+ri2ro = converter.ri2ro
 
 @py2ri.register(PandasDataFrame)
 def py2ri_pandasdataframe(obj):
@@ -116,11 +119,11 @@ def activate():
     if original_converter is not None: 
         return
 
-    original_converter = conversion.make_converter('snapshot before pandas conversion',
-                                                   template=conversion.converter)
-    numpy2ri.activate()
-    new_converter = conversion.make_converter('snapshot before pandas conversion',
+    original_converter = conversion.Converter('snapshot before pandas conversion',
                                               template=conversion.converter)
+    numpy2ri.activate()
+    new_converter = conversion.Converter('snapshot before pandas conversion',
+                                         template=conversion.converter)
     numpy2ri.deactivate()
 
     for k,v in py2ri.registry.items():
@@ -143,8 +146,7 @@ def activate():
             continue
         new_converter.ri2py.register(k, v)
 
-    conversion.converter = new_converter
-    name, conversion.ri2ro, conversion.py2ri, conversion.py2ro, conversion.ri2py, lineage = new_converter
+    conversion.set_conversion(new_converter)
 
 def deactivate():
     global original_converter
@@ -154,8 +156,6 @@ def deactivate():
     if original_converter is None:
         return
 
-    conversion.converter = original_converter
-    name, conversion.ri2ro, conversion.py2ri, conversion.py2ro, conversion.ri2py, lineage = original_converter
-
+    conversion.set_conversion(original_converter)
     original_converter = None
 
